@@ -17,7 +17,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 # 
-# $Id: Document.py,v 1.16 2000/04/14 11:18:50 fredgo Exp $
+# $Id: Document.py,v 1.18 2000/05/11 09:03:14 fredgo Exp $
 
 ''' This module defines a Document class '''
 
@@ -166,7 +166,8 @@ class Document (Connector.Publisher):
         self.sort_dg   = None
         self.lyx       = None
         self.changed   = 0
-
+        self.directory = None
+        
         self.redisplay_index ()
         return
 
@@ -346,11 +347,16 @@ class Document (Connector.Publisher):
         if not self.confirm (): return
 
         # get a new file name
-        (url, how) = FileSelector.URLFileSelection (_("Open file")).run ()
+        (url, how) = FileSelector.URLFileSelection (_("Open file"),
+                                                    directory = self.directory).run ()
 
         if url is None: return
-
         self.open_document (url, how)
+
+        # memorize the current path in the case of a file
+        url = Fields.URL (url)
+        if url.url [0] == 'file':
+            self.directory = os.path.split (url.url [2]) [0] + '/'
         return
 
     
@@ -409,7 +415,7 @@ class Document (Connector.Publisher):
     
     def save_document_as (self, * arg):
         # get a new file name
-        (url, how) = FileSelector.URLFileSelection (_("Open file"),
+        (url, how) = FileSelector.URLFileSelection (_("Save As..."),
                                                     url = FALSE, has_auto = FALSE).run ()
 
         if url is None: return
@@ -434,9 +440,19 @@ class Document (Connector.Publisher):
         
         if self.data.key is None:
             # we wrote an anonymous database. Lets reopen it !
-            self.data = Open.bibopen (url, how = how)
-            self.redisplay_index ()
+            try:
+                self.data = Open.bibopen (url, how = how)
+                
+            except (Exceptions.ParserError,
+                    Exceptions.FormatError,
+                    Exceptions.FileError), error:
+                    
+                Utils.set_cursor (self.w, 'normal')
+                Utils.error_dialog (_("Reopen error"), error,
+                                    parent = self.w)
+                return
             
+            self.redisplay_index ()
             self.issue ('open-document', self)
             
         Utils.set_cursor (self.w, 'normal')
